@@ -640,7 +640,6 @@ nsChromeRegistryChrome::OverlayListHash::GetArray(nsIURI* aBase)
   return &entry->mArray;
 }
 
-#ifdef MOZ_XUL
 NS_IMETHODIMP
 nsChromeRegistryChrome::GetStyleOverlays(nsIURI *aChromeURL,
                                          nsISimpleEnumerator **aResult)
@@ -670,7 +669,6 @@ nsChromeRegistryChrome::GetXULOverlays(nsIURI *aChromeURL,
 
   return NS_NewArrayEnumerator(aResult, *parray);
 }
-#endif // MOZ_XUL
 
 nsIURI*
 nsChromeRegistry::ManifestProcessingContext::GetManifestURI()
