@@ -7,12 +7,6 @@
 DOMCI_CLASS(DOMPrototype)
 DOMCI_CLASS(DOMConstructor)
 
-// CSS classes
-DOMCI_CLASS(CSSStyleRule)
-DOMCI_CLASS(CSSImportRule)
-DOMCI_CLASS(CSSMediaRule)
-DOMCI_CLASS(CSSNameSpaceRule)
-
 // XUL classes
 DOMCI_CLASS(XULCommandDispatcher)
 DOMCI_CLASS(XULControllers)
@@ -21,27 +15,11 @@ DOMCI_CLASS(TreeContentView)
 DOMCI_CLASS(XULTemplateBuilder)
 DOMCI_CLASS(XULTreeBuilder)
 
-DOMCI_CLASS(CSSMozDocumentRule)
-DOMCI_CLASS(CSSSupportsRule)
-
-// @font-face in CSS
-DOMCI_CLASS(CSSFontFaceRule)
-
 DOMCI_CLASS(ContentFrameMessageManager)
 DOMCI_CLASS(ContentProcessMessageManager)
 DOMCI_CLASS(ChromeMessageBroadcaster)
 DOMCI_CLASS(ChromeMessageSender)
 
-DOMCI_CLASS(CSSKeyframeRule)
-DOMCI_CLASS(CSSKeyframesRule)
-
-// @counter-style in CSS
-DOMCI_CLASS(CSSCounterStyleRule)
-
-DOMCI_CLASS(CSSPageRule)
-
-DOMCI_CLASS(CSSFontFeatureValuesRule)
-
 DOMCI_CLASS(XULControlElement)
 DOMCI_CLASS(XULLabeledControlElement)
 DOMCI_CLASS(XULButtonElement)
