@@ -18,17 +18,6 @@ extern "C" {
 #endif
 }
 
-#if LIBAVCODEC_VERSION_MAJOR < 55
-#define AV_CODEC_ID_VP6F CODEC_ID_VP6F
-#define AV_CODEC_ID_H264 CODEC_ID_H264
-#define AV_CODEC_ID_AAC CODEC_ID_AAC
-#define AV_CODEC_ID_MP3 CODEC_ID_MP3
-#define AV_CODEC_ID_VP8 CODEC_ID_VP8
-#define AV_CODEC_ID_NONE CODEC_ID_NONE
-#define AV_CODEC_ID_FLAC CODEC_ID_FLAC
-typedef CodecID AVCodecID;
-#endif
-
 #ifdef FFVPX_VERSION
 enum { LIBAV_VER = FFVPX_VERSION };
 #else
