@@ -62,9 +62,13 @@ public:
     return true;
   }
 
+  void QueueNavigationTimingEntry() override;
+
 protected:
   ~PerformanceMainThread();
 
+  void CreateNavigationTimingEntry();
+
   nsISupports* GetAsISupports() override
   {
     return this;
@@ -76,7 +80,6 @@ protected:
   GetPerformanceTimingFromString(const nsAString& aTimingName) override;
 
   void DispatchBufferFullEvent() override;
-  void EnsureDocEntry();
 
   RefPtr<PerformanceEntry> mDocEntry;
   RefPtr<nsDOMNavigationTiming> mDOMTiming;
