@@ -191,14 +191,23 @@ public:
         FLAG_FORMAT_WOFF           = 1 << 6,
         FLAG_FORMAT_WOFF2          = 1 << 7,
 
+        FLAG_FORMAT_OPENTYPE_VARIATIONS = 1 << 8,
+        FLAG_FORMAT_TRUETYPE_VARIATIONS = 1 << 9,
+        FLAG_FORMAT_WOFF_VARIATIONS     = 1 << 10,
+        FLAG_FORMAT_WOFF2_VARIATIONS    = 1 << 11,
+
         // the common formats that we support everywhere
         FLAG_FORMATS_COMMON        = FLAG_FORMAT_OPENTYPE |
                                      FLAG_FORMAT_TRUETYPE |
                                      FLAG_FORMAT_WOFF     |
-                                     FLAG_FORMAT_WOFF2,
+                                     FLAG_FORMAT_WOFF2    |
+                                     FLAG_FORMAT_OPENTYPE_VARIATIONS |
+                                     FLAG_FORMAT_TRUETYPE_VARIATIONS |
+                                     FLAG_FORMAT_WOFF_VARIATIONS     |
+                                     FLAG_FORMAT_WOFF2_VARIATIONS,
 
         // mask of all unused bits, update when adding new formats
-        FLAG_FORMAT_NOT_USED       = ~((1 << 8)-1)
+        FLAG_FORMAT_NOT_USED       = ~((1 << 12)-1)
     };
 
 
