@@ -279,9 +279,9 @@ class JitProfilingFrameIterator
 
     inline JitFrameLayout* framePtr();
     inline JSScript* frameScript();
-    MOZ_MUST_USE bool tryInitWithPC(void* pc);
-    MOZ_MUST_USE bool tryInitWithTable(JitcodeGlobalTable* table, void* pc, JSRuntime* rt,
-                                       bool forLastCallSite);
+    [[nodiscard]] bool tryInitWithPC(void* pc);
+    [[nodiscard]] bool tryInitWithTable(JitcodeGlobalTable* table, void* pc, JSRuntime* rt,
+                                        bool forLastCallSite);
     void fixBaselineReturnAddress();
 
     void moveToNextFrame(CommonFrameLayout* frame);
@@ -323,7 +323,7 @@ class RInstructionResults
 
     ~RInstructionResults();
 
-    MOZ_MUST_USE bool init(JSContext* cx, uint32_t numResults);
+    [[nodiscard]] bool init(JSContext* cx, uint32_t numResults);
     bool isInitialized() const;
     size_t length() const;
 
@@ -444,7 +444,7 @@ class SnapshotIterator
     Value fromInstructionResult(uint32_t index) const;
 
     Value allocationValue(const RValueAllocation& a, ReadMethod rm = RM_Normal);
-    MOZ_MUST_USE bool allocationReadable(const RValueAllocation& a, ReadMethod rm = RM_Normal);
+    [[nodiscard]] bool allocationReadable(const RValueAllocation& a, ReadMethod rm = RM_Normal);
     void writeAllocationValuePayload(const RValueAllocation& a, const Value& v);
     void warnUnreadableAllocation();
 
@@ -481,7 +481,7 @@ class SnapshotIterator
   public:
     // Exhibits frame properties contained in the snapshot.
     uint32_t pcOffset() const;
-    inline MOZ_MUST_USE bool resumeAfter() const {
+    [[nodiscard]] inline bool resumeAfter() const {
         // Inline frames are inlined on calls, which are considered as being
         // resumed on the Call as baseline will push the pc once we return from
         // the call.
@@ -514,12 +514,12 @@ class SnapshotIterator
     // recover instructions. This vector should be registered before the
     // beginning of the iteration. This function is in charge of allocating
     // enough space for all instructions results, and return false iff it fails.
-    MOZ_MUST_USE bool initInstructionResults(MaybeReadFallback& fallback);
+    [[nodiscard]] bool initInstructionResults(MaybeReadFallback& fallback);
 
   protected:
     // This function is used internally for computing the result of the recover
     // instructions.
-    MOZ_MUST_USE bool computeInstructionResults(JSContext* cx, RInstructionResults* results) const;
+    [[nodiscard]] bool computeInstructionResults(JSContext* cx, RInstructionResults* results) const;
 
   public:
     // Handle iterating over frames of the snapshots.
