@@ -74,8 +74,8 @@ class OptimizationTypeInfo
         types_(alloc)
     { }
 
-    MOZ_MUST_USE bool trackTypeSet(TemporaryTypeSet* typeSet);
-    MOZ_MUST_USE bool trackType(TypeSet::Type type);
+    [[nodiscard]] bool trackTypeSet(TemporaryTypeSet* typeSet);
+    [[nodiscard]] bool trackType(TypeSet::Type type);
 
     JS::TrackedTypeSite site() const { return site_; }
     MIRType mirType() const { return mirType_; }
@@ -86,8 +86,8 @@ class OptimizationTypeInfo
 
     HashNumber hash() const;
 
-    MOZ_MUST_USE bool writeCompact(JSContext* cx, CompactBufferWriter& writer,
-                                   UniqueTrackedTypes& uniqueTypes) const;
+    [[nodiscard]] bool writeCompact(JSContext* cx, CompactBufferWriter& writer,
+                                    UniqueTrackedTypes& uniqueTypes) const;
 };
 
 typedef Vector<OptimizationTypeInfo, 1, JitAllocPolicy> TempOptimizationTypeInfoVector;
@@ -113,9 +113,9 @@ class TrackedOptimizations : public TempObject
         currentAttempt_ = UINT32_MAX;
     }
 
-    MOZ_MUST_USE bool trackTypeInfo(OptimizationTypeInfo&& ty);
+    [[nodiscard]] bool trackTypeInfo(OptimizationTypeInfo&& ty);
 
-    MOZ_MUST_USE bool trackAttempt(JS::TrackedStrategy strategy);
+    [[nodiscard]] bool trackAttempt(JS::TrackedStrategy strategy);
     void amendAttempt(uint32_t index);
     void trackOutcome(JS::TrackedOutcome outcome);
     void trackSuccess();
@@ -173,10 +173,10 @@ class UniqueTrackedOptimizations
         sorted_(cx)
     { }
 
-    MOZ_MUST_USE bool init() { return map_.init(); }
-    MOZ_MUST_USE bool add(const TrackedOptimizations* optimizations);
+    [[nodiscard]] bool init() { return map_.init(); }
+    [[nodiscard]] bool add(const TrackedOptimizations* optimizations);
 
-    MOZ_MUST_USE bool sortByFrequency(JSContext* cx);
+    [[nodiscard]] bool sortByFrequency(JSContext* cx);
     bool sorted() const { return !sorted_.empty(); }
     uint32_t count() const { MOZ_ASSERT(sorted()); return sorted_.length(); }
     const SortedVector& sortedVector() const { MOZ_ASSERT(sorted()); return sorted_; }
@@ -406,10 +406,10 @@ class IonTrackedOptimizationsRegion
                           uint8_t* index);
     static void WriteDelta(CompactBufferWriter& writer, uint32_t startDelta, uint32_t length,
                            uint8_t index);
-    static MOZ_MUST_USE bool WriteRun(CompactBufferWriter& writer,
-                                      const NativeToTrackedOptimizations* start,
-                                      const NativeToTrackedOptimizations* end,
-                                      const UniqueTrackedOptimizations& unique);
+    [[nodiscard]] static bool WriteRun(CompactBufferWriter& writer,
+                                       const NativeToTrackedOptimizations* start,
+                                       const NativeToTrackedOptimizations* end,
+                                       const UniqueTrackedOptimizations& unique);
 };
 
 class IonTrackedOptimizationsAttempts
@@ -559,7 +559,7 @@ typedef IonTrackedOptimizationsOffsetsTable<IonTrackedOptimizationsAttempts>
 typedef IonTrackedOptimizationsOffsetsTable<IonTrackedOptimizationsTypeInfo>
     IonTrackedOptimizationsTypesTable;
 
-MOZ_MUST_USE bool
+[[nodiscard]] bool
 WriteIonTrackedOptimizationsTable(JSContext* cx, CompactBufferWriter& writer,
                                   const NativeToTrackedOptimizations* start,
                                   const NativeToTrackedOptimizations* end,
