@@ -13,7 +13,6 @@
 #include "jsobj.h"
 #include "jsstr.h"
 
-#include "builtin/RegExp.h"
 #include "builtin/TypedObject.h"
 
 #include "gc/Heap.h"
@@ -1082,32 +1081,6 @@ RNaNToZero::recover(JSContext* cx, SnapshotIterator& iter) const
     return true;
 }
 
-bool
-MRegExpMatcher::writeRecoverData(CompactBufferWriter& writer) const
-{
-    MOZ_ASSERT(canRecoverOnBailout());
-    writer.writeUnsigned(uint32_t(RInstruction::Recover_RegExpMatcher));
-    return true;
-}
-
-RRegExpMatcher::RRegExpMatcher(CompactBufferReader& reader)
-{}
-
-bool
-RRegExpMatcher::recover(JSContext* cx, SnapshotIterator& iter) const
-{
-    RootedObject regexp(cx, &iter.read().toObject());
-    RootedString input(cx, iter.read().toString());
-    int32_t lastIndex = iter.read().toInt32();
-
-    RootedValue result(cx);
-    if (!RegExpMatcherRaw(cx, regexp, input, lastIndex, nullptr, &result))
-        return false;
-
-    iter.storeInstructionResult(result);
-    return true;
-}
-
 bool
 MRegExpSearcher::writeRecoverData(CompactBufferWriter& writer) const
 {
