@@ -15,8 +15,7 @@ namespace jit {
 class MIRGenerator;
 class MIRGraph;
 
-MOZ_MUST_USE bool
-Sink(MIRGenerator* mir, MIRGraph& graph);
+[[nodiscard]] bool Sink(MIRGenerator* mir, MIRGraph& graph);
 
 } // namespace jit
 } // namespace js
