@@ -261,19 +261,10 @@ class MacroAssemblerNone : public Assembler
     template <typename T, typename S> void move64(T, S) { MOZ_CRASH(); }
     template <typename T> CodeOffset movWithPatch(T, Register) { MOZ_CRASH(); }
 
-    template <typename T> void loadInt32x1(T, FloatRegister dest) { MOZ_CRASH(); }
-    template <typename T> void loadInt32x2(T, FloatRegister dest) { MOZ_CRASH(); }
-    template <typename T> void loadInt32x3(T, FloatRegister dest) { MOZ_CRASH(); }
-    template <typename T> void loadFloat32x3(T, FloatRegister dest) { MOZ_CRASH(); }
-
     template <typename T> void loadPtr(T, Register) { MOZ_CRASH(); }
     template <typename T> void load32(T, Register) { MOZ_CRASH(); }
     template <typename T> void loadFloat32(T, FloatRegister) { MOZ_CRASH(); }
     template <typename T> void loadDouble(T, FloatRegister) { MOZ_CRASH(); }
-    template <typename T> void loadAlignedSimd128Int(T, FloatRegister) { MOZ_CRASH(); }
-    template <typename T> void loadUnalignedSimd128Int(T, FloatRegister) { MOZ_CRASH(); }
-    template <typename T> void loadAlignedSimd128Float(T, FloatRegister) { MOZ_CRASH(); }
-    template <typename T> void loadUnalignedSimd128Float(T, FloatRegister) { MOZ_CRASH(); }
     template <typename T> void loadPrivate(T, Register) { MOZ_CRASH(); }
     template <typename T> void load8SignExtend(T, Register) { MOZ_CRASH(); }
     template <typename T> void load8ZeroExtend(T, Register) { MOZ_CRASH(); }
@@ -286,16 +277,8 @@ class MacroAssemblerNone : public Assembler
     template <typename T, typename S> void store32_NoSecondScratch(T, S) { MOZ_CRASH(); }
     template <typename T, typename S> void storeFloat32(T, S) { MOZ_CRASH(); }
     template <typename T, typename S> void storeDouble(T, S) { MOZ_CRASH(); }
-    template <typename T, typename S> void storeAlignedSimd128Int(T, S) { MOZ_CRASH(); }
-    template <typename T, typename S> void storeUnalignedSimd128Int(T, S) { MOZ_CRASH(); }
-    template <typename T, typename S> void storeAlignedSimd128Float(T, S) { MOZ_CRASH(); }
-    template <typename T, typename S> void storeUnalignedSimd128Float(T, S) { MOZ_CRASH(); }
     template <typename T, typename S> void store8(T, S) { MOZ_CRASH(); }
     template <typename T, typename S> void store16(T, S) { MOZ_CRASH(); }
-    template <typename T, typename S> void storeInt32x1(T, S) { MOZ_CRASH(); }
-    template <typename T, typename S> void storeInt32x2(T, S) { MOZ_CRASH(); }
-    template <typename T, typename S> void storeInt32x3(T, S) { MOZ_CRASH(); }
-    template <typename T, typename S> void storeFloat32x3(T, S) { MOZ_CRASH(); }
     template <typename T, typename S> void store64(T, S) { MOZ_CRASH(); }
 
     template <typename T> void computeEffectiveAddress(T, Register) { MOZ_CRASH(); }
