@@ -1345,11 +1345,11 @@ FreezeObject(JSContext* cx, HandleObject obj)
 extern bool
 TestIntegrityLevel(JSContext* cx, HandleObject obj, IntegrityLevel level, bool* resultp);
 
-extern MOZ_MUST_USE JSObject*
+[[nodiscard]] extern JSObject*
 SpeciesConstructor(JSContext* cx, HandleObject obj, HandleObject defaultCtor,
                    bool (*isDefaultSpecies)(JSContext*, JSFunction*));
 
-extern MOZ_MUST_USE JSObject*
+[[nodiscard]] extern JSObject*
 SpeciesConstructor(JSContext* cx, HandleObject obj, JSProtoKey ctorKey,
                    bool (*isDefaultSpecies)(JSContext*, JSFunction*));
 
