@@ -4,8 +4,8 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 465460;
-var summary = 'TM: valueOf in a loop: do not assert';
+var BUGNUMBER = 467495;
+var summary = 'TCF_FUN_CLOSURE_VS_VAR is necessary';
 var actual = '';
 var expect = '';
 
@@ -19,9 +19,11 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
- 
-  for each (let j in [null, 2, 3]) { }
 
+  expect = '1';
+
+  function g(x) { if (1) function x() {} return x; }
+  print(actual = g(1) + '');
 
   reportCompare(expect, actual, summary);
 
