@@ -4,38 +4,21 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch07/7.6/7.6.1/7.6.1-4-6.js
- * @description Allow reserved words as property names by set function within an object, verified with hasOwnProperty: continue, for, switch
+ * @path ch07/7.6/7.6.1/7.6.1-2-10.js
+ * @description Allow reserved words as property names by dot operator assignment, verified with hasOwnProperty: in, try, class
  */
 
 
 function testcase() {
-        var test0 = 0, test1 = 1, test2 = 2;
-        var tokenCodes  = {
-            set continue(value){
-                test0 = value;
-            },
-            get continue(){
-                return test0;
-            },
-            set for(value){
-                test1 = value;
-            },
-            get for(){
-                return test1;
-            },
-            set switch(value){
-                test2 = value;
-            },
-            get switch(){
-                return test2;
-            }
-        };      
+        var tokenCodes = {};
+        tokenCodes.in = 0;
+        tokenCodes.try = 1;
+        tokenCodes.class = 2;
         var arr = [
-            'continue', 
-            'for',
-            'switch'
-            ];
+            'in', 
+            'try',
+            'class'
+        ];
         for(var p in tokenCodes) {       
             for(var p1 in arr) {                
                 if(arr[p1] === p) {
