@@ -4,14 +4,15 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch10/10.4/10.4.3/10.4.3-1-59-s.js
- * @description Strict Mode - checking 'this' (Injected getter includes strict directive prologue)
- * @onlyStrict
+ * @path ch10/10.1/10.1.1/10.1.1-1-s.js
+ * @description Strict Mode - Use Strict Directive Prologue is 'use  strict'; which contains two space between 'use' and 'strict'
+ * @noStrict
  */
-    
+
+
 function testcase() {
-var o = {};
-Object.defineProperty(o, "foo", { get: function() { "use strict"; return this; } });
-return o.foo===o;
-}
-runTestCase(testcase);
\ No newline at end of file
+        "use  strict";
+        var public = 1;
+        return public === 1;
+    }
+runTestCase(testcase);
