@@ -4,27 +4,20 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch11/11.1/11.1.5/11.1.5_6-2-1-s.js
- * @description Strict Mode - SyntaxError is thrown when an assignment to a reserved word or a future reserved word is contained in strict code
+ * @path ch11/11.13/11.13.2/11.13.2-6-2-s.js
+ * @description Strict Mode - SyntaxError is thrown if the identifier eval appear as the LeftHandSideExpression of a Compound Assignment operator(/=)
  * @onlyStrict
  */
 
 
 function testcase() {
         "use strict";
-
+        var blah = eval;
         try {
-            eval("var obj = {\
-                get _11_1_5_6_2_1() {\
-                   public = 42;\
-                   return public;\
-                }\
-            };");
-
-            var _11_1_5_6_2_1 = obj._11_1_5_6_2_1;
+            eval("eval /= 20;");
             return false;
         } catch (e) {
-            return e instanceof SyntaxError;
+            return e instanceof SyntaxError && blah === eval;
         }
     }
 runTestCase(testcase);
