@@ -161,11 +161,11 @@ class SavedStacks {
         creatingSavedFrame(false)
     { }
 
-    MOZ_MUST_USE bool init();
+    [[nodiscard]] bool init();
     bool initialized() const { return frames.initialized(); }
-    MOZ_MUST_USE bool saveCurrentStack(JSContext* cx, MutableHandleSavedFrame frame,
+    [[nodiscard]] bool saveCurrentStack(JSContext* cx, MutableHandleSavedFrame frame,
                                        JS::StackCapture&& capture = JS::StackCapture(JS::AllFrames()));
-    MOZ_MUST_USE bool copyAsyncStack(JSContext* cx, HandleObject asyncStack,
+    [[nodiscard]] bool copyAsyncStack(JSContext* cx, HandleObject asyncStack,
                                      HandleString asyncCause,
                                      MutableHandleSavedFrame adoptedStack,
                                      uint32_t maxFrameCount = 0);
@@ -218,10 +218,10 @@ class SavedStacks {
         }
     };
 
-    MOZ_MUST_USE bool insertFrames(JSContext* cx, FrameIter& iter,
+    [[nodiscard]] bool insertFrames(JSContext* cx, FrameIter& iter,
                                    MutableHandleSavedFrame frame,
                                    JS::StackCapture&& capture);
-    MOZ_MUST_USE bool adoptAsyncStack(JSContext* cx, HandleSavedFrame asyncStack,
+    [[nodiscard]] bool adoptAsyncStack(JSContext* cx, HandleSavedFrame asyncStack,
                                       HandleString asyncCause,
                                       MutableHandleSavedFrame adoptedStack,
                                       uint32_t maxFrameCount);
@@ -291,7 +291,7 @@ class SavedStacks {
     using PCLocationMap = GCHashMap<PCKey, LocationValue, PCLocationHasher, SystemAllocPolicy>;
     PCLocationMap pcLocationMap;
 
-    MOZ_MUST_USE bool getLocation(JSContext* cx, const FrameIter& iter,
+    [[nodiscard]] bool getLocation(JSContext* cx, const FrameIter& iter,
                                   MutableHandle<LocationValue> locationp);
 };
 
