@@ -1,6 +1,7 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  *
  * Copyright 2016 Mozilla Foundation
+ * Copyright 2023 Moonchild Productions
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -150,7 +151,7 @@ class AstDecodeContext
     void popBack() { return exprs().popBack(); }
     AstDecodeStackItem popCopy() { return exprs().popCopy(); }
     AstDecodeStackItem& top() { return exprs().back(); }
-    MOZ_MUST_USE bool push(AstDecodeStackItem item) { return exprs().append(item); }
+    [[nodiscard]] bool push(AstDecodeStackItem item) { return exprs().append(item); }
 
     bool needFirst() {
         for (size_t i = depths().back(); i < exprs().length(); ++i) {
