@@ -1,6 +1,7 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  *
  * Copyright 2015 Mozilla Foundation
+ * Copyright 2023 Moonchild Productions
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -33,7 +34,7 @@ namespace wasm {
 // Translate the given binary representation of a wasm module into the module's textual
 // representation.
 
-MOZ_MUST_USE bool
+[[nodiscard]] bool
 BinaryToText(JSContext* cx, const uint8_t* bytes, size_t length, StringBuffer& buffer,
              GeneratedSourceMap* sourceMap = nullptr);
 
