@@ -324,11 +324,11 @@ public:
     // two-bit values:
     //   bit 0 = the eOrientationMask value
     //   bit 1 = the eBlockFlowMask value
-    static const mozilla::css::Side kLogicalBlockSides[][2] = {
-      { NS_SIDE_TOP,    NS_SIDE_BOTTOM },  // horizontal-tb
-      { NS_SIDE_RIGHT,  NS_SIDE_LEFT   },  // vertical-rl
-      { NS_SIDE_BOTTOM, NS_SIDE_TOP    },  // (horizontal-bt)
-      { NS_SIDE_LEFT,   NS_SIDE_RIGHT  },  // vertical-lr
+    static const mozilla::Side kLogicalBlockSides[][2] = {
+      { eSideTop,    eSideBottom },  // horizontal-tb
+      { eSideRight,  eSideLeft   },  // vertical-rl
+      { eSideBottom, eSideTop    },  // (horizontal-bt)
+      { eSideLeft,   eSideRight  },  // vertical-lr
     };
 
     // Ignore the SIDEWAYS_MASK bit of the writing-mode value, as this has no
@@ -352,23 +352,23 @@ public:
     // is no horizontal-bt writing-mode, and no text-orientation value that
     // produces "inverted" text. (The former 'sideways-left' value, no longer
     // in the spec, would have produced this in vertical-rl mode.)
-    static const mozilla::css::Side kLogicalInlineSides[][2] = {
-      { NS_SIDE_LEFT,   NS_SIDE_RIGHT  },  // horizontal-tb               ltr
-      { NS_SIDE_TOP,    NS_SIDE_BOTTOM },  // vertical-rl                 ltr
-      { NS_SIDE_RIGHT,  NS_SIDE_LEFT   },  // horizontal-tb               rtl
-      { NS_SIDE_BOTTOM, NS_SIDE_TOP    },  // vertical-rl                 rtl
-      { NS_SIDE_RIGHT,  NS_SIDE_LEFT   },  // (horizontal-bt)  (inverted) ltr
-      { NS_SIDE_TOP,    NS_SIDE_BOTTOM },  // sideways-lr                 rtl
-      { NS_SIDE_LEFT,   NS_SIDE_RIGHT  },  // (horizontal-bt)  (inverted) rtl
-      { NS_SIDE_BOTTOM, NS_SIDE_TOP    },  // sideways-lr                 ltr
-      { NS_SIDE_LEFT,   NS_SIDE_RIGHT  },  // horizontal-tb    (inverted) rtl
-      { NS_SIDE_TOP,    NS_SIDE_BOTTOM },  // vertical-rl      (inverted) rtl
-      { NS_SIDE_RIGHT,  NS_SIDE_LEFT   },  // horizontal-tb    (inverted) ltr
-      { NS_SIDE_BOTTOM, NS_SIDE_TOP    },  // vertical-rl      (inverted) ltr
-      { NS_SIDE_LEFT,   NS_SIDE_RIGHT  },  // (horizontal-bt)             ltr
-      { NS_SIDE_TOP,    NS_SIDE_BOTTOM },  // vertical-lr                 ltr
-      { NS_SIDE_RIGHT,  NS_SIDE_LEFT   },  // (horizontal-bt)             rtl
-      { NS_SIDE_BOTTOM, NS_SIDE_TOP    },  // vertical-lr                 rtl
+    static const mozilla::Side kLogicalInlineSides[][2] = {
+      { eSideLeft,   eSideRight  },  // horizontal-tb               ltr
+      { eSideTop,    eSideBottom },  // vertical-rl                 ltr
+      { eSideRight,  eSideLeft   },  // horizontal-tb               rtl
+      { eSideBottom, eSideTop    },  // vertical-rl                 rtl
+      { eSideRight,  eSideLeft   },  // (horizontal-bt)  (inverted) ltr
+      { eSideTop,    eSideBottom },  // sideways-lr                 rtl
+      { eSideLeft,   eSideRight  },  // (horizontal-bt)  (inverted) rtl
+      { eSideBottom, eSideTop    },  // sideways-lr                 ltr
+      { eSideLeft,   eSideRight  },  // horizontal-tb    (inverted) rtl
+      { eSideTop,    eSideBottom },  // vertical-rl      (inverted) rtl
+      { eSideRight,  eSideLeft   },  // horizontal-tb    (inverted) ltr
+      { eSideBottom, eSideTop    },  // vertical-rl      (inverted) ltr
+      { eSideLeft,   eSideRight  },  // (horizontal-bt)             ltr
+      { eSideTop,    eSideBottom },  // vertical-lr                 ltr
+      { eSideRight,  eSideLeft   },  // (horizontal-bt)             rtl
+      { eSideBottom, eSideTop    },  // vertical-lr                 rtl
     };
 
     // Inline axis sides depend on all three of writing-mode, text-orientation
@@ -404,7 +404,7 @@ public:
    * given the current writing mode.
    * (This is the inverse of the PhysicalSide() method above.)
    */
-  LogicalSide LogicalSideForPhysicalSide(mozilla::css::Side aSide) const
+  LogicalSide LogicalSideForPhysicalSide(mozilla::Side aSide) const
   {
     // indexes are four-bit values:
     //   bit 0 = the eOrientationMask value
