@@ -953,10 +953,11 @@ inDOMUtils::GetCSSValuesForProperty(const nsAString& aProperty,
       GetOtherValuesForProperty(propertyParserVariant, array);
     }
   }
-  // All CSS properties take initial, inherit and unset.
+  // All CSS properties take initial, inherit, unset, and revert.
   InsertNoDuplicates(array, NS_LITERAL_STRING("initial"));
   InsertNoDuplicates(array, NS_LITERAL_STRING("inherit"));
   InsertNoDuplicates(array, NS_LITERAL_STRING("unset"));
+  InsertNoDuplicates(array, NS_LITERAL_STRING("revert"));
 
   *aLength = array.Length();
   char16_t** ret =
