@@ -8,7 +8,6 @@
 #include "mozilla/dom/BindingDeclarations.h" // for Optional<>
 #include "mozilla/dom/CSSRuleList.h"
 #include "mozilla/dom/ShadowRoot.h"
-#include "mozilla/ServoStyleSheet.h"
 #include "mozilla/StyleSheetInlines.h"
 #include "mozilla/CSSStyleSheet.h"
 
@@ -20,11 +19,10 @@ using namespace mozilla::dom;
 
 namespace mozilla {
 
-StyleSheet::StyleSheet(StyleBackendType aType, css::SheetParsingMode aParsingMode)
+StyleSheet::StyleSheet(css::SheetParsingMode aParsingMode)
   : mDocument(nullptr)
   , mOwningNode(nullptr)
   , mParsingMode(aParsingMode)
-  , mType(aType)
   , mDisabled(false)
   , mDocumentAssociationMode(NotOwnedByDocument)
 {
@@ -37,7 +35,6 @@ StyleSheet::StyleSheet(const StyleSheet& aCopy,
   , mDocument(aDocumentToUse)
   , mOwningNode(aOwningNodeToUse)
   , mParsingMode(aCopy.mParsingMode)
-  , mType(aCopy.mType)
   , mDisabled(aCopy.mDisabled)
     // We only use this constructor during cloning.  It's the cloner's
     // responsibility to notify us if we end up being owned by a document.
@@ -82,7 +79,7 @@ StyleSheet::IsComplete() const
 void
 StyleSheet::SetComplete()
 {
-  NS_ASSERTION(!IsGecko() || !AsGecko()->mDirty,
+  NS_ASSERTION(!AsConcrete()->mDirty,
                "Can't set a dirty sheet complete!");
   SheetInfo().mComplete = true;
   if (mDocument && !mDisabled) {
@@ -138,11 +135,7 @@ StyleSheet::SetDisabled(bool aDisabled)
 {
   // DOM method, so handle BeginUpdate/EndUpdate
   MOZ_AUTO_DOC_UPDATE(mDocument, UPDATE_STYLE, true);
-  if (IsGecko()) {
-    AsGecko()->SetEnabled(!aDisabled);
-  } else {
-    MOZ_CRASH("stylo: unimplemented SetEnabled");
-  }
+  AsConcrete()->SetEnabled(!aDisabled);
   return NS_OK;
 }
 
@@ -229,12 +222,6 @@ StyleSheet::DeleteRule(uint32_t aIndex)
 
 // WebIDL CSSStyleSheet API
 
-#define FORWARD_INTERNAL(method_, args_) \
-  if (IsServo()) { \
-    return AsServo()->method_ args_; \
-  } \
-  return AsGecko()->method_ args_;
-
 dom::CSSRuleList*
 StyleSheet::GetCssRules(nsIPrincipal& aSubjectPrincipal,
                         ErrorResult& aRv)
@@ -242,7 +229,7 @@ StyleSheet::GetCssRules(nsIPrincipal& aSubjectPrincipal,
   if (!AreRulesAvailable(aSubjectPrincipal, aRv)) {
     return nullptr;
   }
-  FORWARD_INTERNAL(GetCssRulesInternal, (aRv))
+  return AsConcrete()->GetCssRulesInternal(aRv);
 }
 
 uint32_t
@@ -253,7 +240,7 @@ StyleSheet::InsertRule(const nsAString& aRule, uint32_t aIndex,
   if (!AreRulesAvailable(aSubjectPrincipal, aRv)) {
     return 0;
   }
-  FORWARD_INTERNAL(InsertRuleInternal, (aRule, aIndex, aRv))
+  return AsConcrete()->InsertRuleInternal(aRule, aIndex, aRv);
 }
 
 void
@@ -264,7 +251,7 @@ StyleSheet::DeleteRule(uint32_t aIndex,
   if (!AreRulesAvailable(aSubjectPrincipal, aRv)) {
     return;
   }
-  FORWARD_INTERNAL(DeleteRuleInternal, (aIndex, aRv))
+  AsConcrete()->DeleteRuleInternal(aIndex, aRv);
 }
 
 int32_t
@@ -288,13 +275,11 @@ StyleSheet::AddRule(const nsAString& aSelector, const nsAString& aBlock,
   auto index =
       aIndex.WasPassed() ? aIndex.Value() : GetCssRules(aSubjectPrincipal, aRv)->Length();
 
-  FORWARD_INTERNAL(InsertRuleInternal, (rule, index, aRv));
+  return AsConcrete()->InsertRuleInternal(rule, index, aRv);
   // As per Microsoft documentation, always return -1.
   return -1;
 }
 
-#undef FORWARD_INTERNAL
-
 void
 StyleSheet::SubjectSubsumesInnerPrincipal(nsIPrincipal& aSubjectPrincipal,
                                           ErrorResult& aRv)
