@@ -197,7 +197,6 @@ CSS_KEY(collapse, collapse)
 CSS_KEY(color, color)
 CSS_KEY(color-burn, color_burn)
 CSS_KEY(color-dodge, color_dodge)
-CSS_KEY(color-mix, color_mix)
 CSS_KEY(common-ligatures, common_ligatures)
 CSS_KEY(column, column)
 CSS_KEY(column-reverse, column_reverse)
@@ -313,7 +312,6 @@ CSS_KEY(horizontal, horizontal)
 CSS_KEY(horizontal-tb, horizontal_tb)
 CSS_KEY(hue, hue)
 CSS_KEY(hue-rotate, hue_rotate)
-CSS_KEY(hsl, hsl)
 CSS_KEY(hz, hz)
 CSS_KEY(icon, icon)
 CSS_KEY(ignore, ignore)
