@@ -3372,18 +3372,15 @@ namespace mozilla {
 
 CSSLayerStatementRule::CSSLayerStatementRule(
                        const nsTArray<nsString>& aNameList,
-                       const nsTArray<nsTArray<nsString>>& aPathList,
                        uint32_t aLineNumber, uint32_t aColumnNumber)
   : Rule(aLineNumber, aColumnNumber)
   , mNameList(aNameList)
-  , mPathList(aPathList)
 {
 }
 
 CSSLayerStatementRule::CSSLayerStatementRule(const CSSLayerStatementRule& aCopy)
   : Rule(aCopy)
   , mNameList(aCopy.mNameList)
-  , mPathList(aCopy.mPathList)
 {
 }
 
@@ -3410,7 +3407,6 @@ NS_IMPL_CYCLE_COLLECTION_CLASS(CSSLayerStatementRule)
 
 NS_IMPL_CYCLE_COLLECTION_UNLINK_BEGIN(CSSLayerStatementRule)
   tmp->mNameList.Clear();
-  tmp->mPathList.Clear();
 NS_IMPL_CYCLE_COLLECTION_UNLINK_END
 
 NS_IMPL_CYCLE_COLLECTION_TRAVERSE_BEGIN_INHERITED(CSSLayerStatementRule, mozilla::css::Rule)
@@ -3462,28 +3458,10 @@ CSSLayerStatementRule::GetNameList(nsTArray<nsString>& aResult)
   aResult = mNameList;
 }
 
-void
-CSSLayerStatementRule::GetPathList(nsTArray<nsTArray<nsString>>& aResult)
-{
-  aResult = mPathList;
-}
-
 /* virtual */ size_t
 CSSLayerStatementRule::SizeOfIncludingThis(MallocSizeOf aMallocSizeOf) const
 {
-  size_t n = aMallocSizeOf(this);
-  n += mNameList.ShallowSizeOfExcludingThis(aMallocSizeOf);
-  for (const nsString& s : mNameList) {
-    n += s.SizeOfExcludingThisIfUnshared(aMallocSizeOf);
-  }
-  n += mPathList.ShallowSizeOfExcludingThis(aMallocSizeOf);
-  for (const nsTArray<nsString>& inner : mPathList) {
-    n += inner.ShallowSizeOfExcludingThis(aMallocSizeOf);
-    for (const nsString& str : inner) {
-      n += str.SizeOfExcludingThisIfUnshared(aMallocSizeOf);
-    }
-  }
-  return n;
+  return aMallocSizeOf(this);
 }
 
 /* virtual */ JSObject*
@@ -3499,11 +3477,9 @@ CSSLayerStatementRule::WrapObject(JSContext* aCx,
 //
 
 CSSLayerBlockRule::CSSLayerBlockRule(const nsString& aName,
-                                     const nsTArray<nsString>& aPath,
                                      uint32_t aLineNumber, uint32_t aColumnNumber)
   : css::GroupRule(aLineNumber, aColumnNumber)
   , mName(aName)
-  , mPath(aPath)
 {
 }
 
@@ -3514,7 +3490,6 @@ CSSLayerBlockRule::~CSSLayerBlockRule()
 CSSLayerBlockRule::CSSLayerBlockRule(const CSSLayerBlockRule& aCopy)
   : css::GroupRule(aCopy)
   , mName(aCopy.mName)
-  , mPath(aCopy.mPath)
 {
 }
 
@@ -3547,32 +3522,15 @@ CSSLayerBlockRule::UseForPresentation(nsPresContext* aPresContext,
   return true;
 }
 
-void
-CSSLayerBlockRule::GetPath(nsTArray<nsString>& aResult)
-{
-  aResult = mPath;
-}
-
-NS_IMPL_ADDREF_INHERITED(CSSLayerBlockRule, GroupRule)
-NS_IMPL_RELEASE_INHERITED(CSSLayerBlockRule, GroupRule)
+NS_IMPL_ADDREF_INHERITED(CSSLayerBlockRule, css::GroupRule)
+NS_IMPL_RELEASE_INHERITED(CSSLayerBlockRule, css::GroupRule)
 
 // QueryInterface implementation for CSSLayerBlockRule
-NS_INTERFACE_MAP_BEGIN_CYCLE_COLLECTION(CSSLayerBlockRule)
+NS_INTERFACE_MAP_BEGIN(CSSLayerBlockRule)
   NS_INTERFACE_MAP_ENTRY(nsIDOMCSSGroupingRule)
   NS_INTERFACE_MAP_ENTRY(nsIDOMCSSLayerBlockRule)
 NS_INTERFACE_MAP_END_INHERITING(GroupRule)
 
-NS_IMPL_CYCLE_COLLECTION_CLASS(CSSLayerBlockRule)
-
-NS_IMPL_CYCLE_COLLECTION_UNLINK_BEGIN_INHERITED(CSSLayerBlockRule,
-                                                GroupRule)
-  tmp->mPath.Clear();
-NS_IMPL_CYCLE_COLLECTION_UNLINK_END
-
-NS_IMPL_CYCLE_COLLECTION_TRAVERSE_BEGIN_INHERITED(CSSLayerBlockRule,
-                                                  GroupRule)
-NS_IMPL_CYCLE_COLLECTION_TRAVERSE_END
-
 uint16_t
 CSSLayerBlockRule::Type() const
 {
@@ -3608,9 +3566,9 @@ CSSLayerBlockRule::DeleteRule(uint32_t aIndex)
 
 // nsIDOMCSSLayerBlockRule methods
 NS_IMETHODIMP
-CSSLayerBlockRule::GetName(nsAString& aLayerName)
+CSSLayerBlockRule::GetName(nsAString& aConditionText)
 {
-  aLayerName.Assign(mName);
+  aConditionText.Assign(mName);
   return NS_OK;
 }
 
@@ -3620,10 +3578,6 @@ CSSLayerBlockRule::SizeOfIncludingThis(MallocSizeOf aMallocSizeOf) const
   size_t n = aMallocSizeOf(this);
   n += css::GroupRule::SizeOfExcludingThis(aMallocSizeOf);
   n += mName.SizeOfExcludingThisIfUnshared(aMallocSizeOf);
-  n += mPath.ShallowSizeOfExcludingThis(aMallocSizeOf);
-  for (const nsString& s : mPath) {
-    n += s.SizeOfExcludingThisIfUnshared(aMallocSizeOf);
-  }
   return n;
 }
 
