@@ -186,6 +186,7 @@ enum class StyleUserSelect : uint8_t {
   None,
   Text,
   Element,
+  Contain,
   Elements,
   All,
   Toggle,
@@ -1262,8 +1263,12 @@ enum class StyleDisplay : uint8_t {
 #define NS_STYLE_DISPLAY_MODE_FULLSCREEN        3
 
 // prefers-color-scheme
-#define NS_STYLE_PREFERS_COLOR_SCHEME_LIGHT	0
-#define NS_STYLE_PREFERS_COLOR_SCHEME_DARK	1
+#define NS_STYLE_PREFERS_COLOR_SCHEME_LIGHT     0
+#define NS_STYLE_PREFERS_COLOR_SCHEME_DARK      1
+
+// prefers-reduced-motion
+#define NS_STYLE_PREFERS_FULL_MOTION            0
+#define NS_STYLE_PREFERS_REDUCED_MOTION         1
 
 } // namespace mozilla
 
