@@ -3,13 +3,6 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-//
-// Eric Vaughan
-// Netscape Communications
-//
-// See documentation in associated header file
-//
-
 #include "nsImageBoxFrame.h"
 #include "nsGkAtoms.h"
 #include "nsRenderingContext.h"
@@ -26,7 +19,6 @@
 #include "nsIPresShell.h"
 #include "nsIDocument.h"
 #include "nsImageMap.h"
-#include "nsILinkHandler.h"
 #include "nsIURL.h"
 #include "nsILoadGroup.h"
 #include "nsContainerFrame.h"
