@@ -11,7 +11,7 @@
 #include "mozilla/BasePrincipal.h"
 #include "nsICertBlocklist.h"
 #include "nsString.h"
-#include "pkix/pkixtypes.h"
+#include "mozpkix/pkixtypes.h"
 #include "secmodt.h"
 
 namespace mozilla { namespace psm {
@@ -102,16 +102,26 @@ public:
                    mozilla::pkix::EndEntityOrCA endEntityOrCA,
                    unsigned int modulusSizeInBits) override;
 
-  virtual Result VerifyRSAPKCS1SignedDigest(
-                   const mozilla::pkix::SignedDigest& signedDigest,
+  virtual Result VerifyRSAPKCS1SignedData(
+                   mozilla::pkix::Input data,
+                   mozilla::pkix::DigestAlgorithm digestAlgorithm,
+                   mozilla::pkix::Input signature,
+                   mozilla::pkix::Input subjectPublicKeyInfo) override;
+
+  virtual Result VerifyRSAPSSSignedData(
+                   mozilla::pkix::Input data,
+                   mozilla::pkix::DigestAlgorithm digestAlgorithm,
+                   mozilla::pkix::Input signature,
                    mozilla::pkix::Input subjectPublicKeyInfo) override;
 
   virtual Result CheckECDSACurveIsAcceptable(
                    mozilla::pkix::EndEntityOrCA endEntityOrCA,
                    mozilla::pkix::NamedCurve curve) override;
 
-  virtual Result VerifyECDSASignedDigest(
-                   const mozilla::pkix::SignedDigest& signedDigest,
+  virtual Result VerifyECDSASignedData(
+                   mozilla::pkix::Input data,
+                   mozilla::pkix::DigestAlgorithm digestAlgorithm,
+                   mozilla::pkix::Input signature,
                    mozilla::pkix::Input subjectPublicKeyInfo) override;
 
   virtual Result DigestBuf(mozilla::pkix::Input item,
