@@ -21,17 +21,19 @@
  * SOFTWARE.
  */
 
-#include "libintvector.h"
-#include "kremlin/internal/types.h"
-#include "kremlin/lowstar_endianness.h"
-#include <string.h>
-#include <stdbool.h>
-
 #ifndef __Hacl_Chacha20_Vec256_H
 #define __Hacl_Chacha20_Vec256_H
 
-#include "Hacl_Chacha20.h"
-#include "Hacl_Kremlib.h"
+#if defined(__cplusplus)
+extern "C" {
+#endif
+
+#include <string.h>
+#include "krml/internal/types.h"
+#include "krml/lowstar_endianness.h"
+#include "krml/internal/target.h"
+
+#include "Hacl_Krmllib.h"
 
 void
 Hacl_Chacha20_Vec256_chacha20_encrypt_256(
@@ -39,7 +41,7 @@ Hacl_Chacha20_Vec256_chacha20_encrypt_256(
     uint8_t *out,
     uint8_t *text,
     uint8_t *key,
-    uint8_t *n1,
+    uint8_t *n,
     uint32_t ctr);
 
 void
@@ -48,8 +50,12 @@ Hacl_Chacha20_Vec256_chacha20_decrypt_256(
     uint8_t *out,
     uint8_t *cipher,
     uint8_t *key,
-    uint8_t *n1,
+    uint8_t *n,
     uint32_t ctr);
 
+#if defined(__cplusplus)
+}
+#endif
+
 #define __Hacl_Chacha20_Vec256_H_DEFINED
 #endif
