@@ -114,6 +114,15 @@ XPCOMUtils.defineLazyGetter(this, "gABI", function() {
     LOG("BlockList Global gABI: XPCOM ABI unknown.");
   }
 
+#ifdef XP_MACOSX
+  // Mac universal build should report a different ABI than either macppc
+  // or mactel.
+  let macutils = Cc["@mozilla.org/xpcom/mac-utils;1"].
+                 getService(Ci.nsIMacUtils);
+
+  if (macutils.isUniversalBinary)
+    abi += "-u-" + macutils.architecturesInBinary;
+#endif
   return abi;
 });
 
@@ -740,10 +749,7 @@ Blocklist.prototype = {
       return;
     }
 
-    let telemetry = Services.telemetry;
-
     if (this._isBlocklistPreloaded()) {
-      telemetry.getHistogramById("BLOCKLIST_SYNC_FILE_LOAD").add(false);
       this._loadBlocklistFromString(this._preloadedBlocklistContent);
       delete this._preloadedBlocklistContent;
       return;
@@ -754,8 +760,6 @@ Blocklist.prototype = {
       return;
     }
 
-    telemetry.getHistogramById("BLOCKLIST_SYNC_FILE_LOAD").add(true);
-
     let text = "";
     let fstream = null;
     let cstream = null;
@@ -1039,7 +1043,7 @@ Blocklist.prototype = {
 
   // <gfxBlacklistEntry blockID="g60">
   //   <os>WINNT 6.0</os>
-  //   <osversion>14</osversion> currently only used for Android
+  //   <osversion>14</osversion>
   //   <versionRange minVersion="42.0" maxVersion="13.0b2"/>
   //   <vendor>0x8086</vendor>
   //   <devices>
