@@ -39,6 +39,10 @@ var snapshotFormatters = {
     $("application-box").textContent = data.name;
     $("useragent-box").textContent = data.userAgent;
     $("os-box").textContent = data.osVersion;
+    let cpucaps = navigator.cpuHasSSE2?"SSE2 ":"";
+    cpucaps    += navigator.cpuHasAVX?"AVX ":"";
+    cpucaps    += navigator.cpuHasAVX2?"AVX2 ":"";
+    $("cpucap-box").textContent = cpucaps;
     $("binary-box").textContent = Services.dirsvc.get("XREExeF", Ci.nsIFile).path;
     $("supportLink").href = data.supportURL;
     let version = Services.appinfo.version;
